@@ -215,7 +215,7 @@
 /* #undef HAVE_PORT_CREATE */
 /* #undef HAVE_POSIX_FALLOCATE */
 #define HAVE_PREAD 1
-#define HAVE_PAUSE_INSTRUCTION 1
+/* #undef HAVE_PAUSE_INSTRUCTION */
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
@@ -346,10 +346,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   8
-#define SIZEOF_VOIDP  8
-#define SIZEOF_CHARP  8
-#define SIZEOF_SIZE_T 8
+#define SIZEOF_LONG   4
+#define SIZEOF_VOIDP  4
+#define SIZEOF_CHARP  4
+#define SIZEOF_SIZE_T 4
 #endif
 
 #define SIZEOF_CHAR 1
@@ -371,7 +371,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 8
+#define SIZEOF_ULONG 4
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -472,7 +472,7 @@
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
 /* #undef MY_ATOMIC_MODE_RWLOCKS */
-#define HAVE_GCC_ATOMIC_BUILTINS 1
+/* #undef HAVE_GCC_ATOMIC_BUILTINS */
 /* #undef HAVE_GCC_C11_ATOMICS */
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef HAVE_DECL_SHM_HUGETLB */
@@ -490,8 +490,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "amd64"
-#define DEFAULT_MACHINE "amd64"
+#define MACHINE_TYPE "arm"
+#define DEFAULT_MACHINE "arm"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -608,20 +608,20 @@
   Important storage engines (those that really need define 
   WITH_<ENGINE>_STORAGE_ENGINE for the whole server)
 */
-#define WITH_MYISAM_STORAGE_ENGINE 1
-#define WITH_MYISAMMRG_STORAGE_ENGINE 1
-#define WITH_HEAP_STORAGE_ENGINE 1
+/* #undef WITH_MYISAM_STORAGE_ENGINE */
+/* #undef WITH_MYISAMMRG_STORAGE_ENGINE */
+/* #undef WITH_HEAP_STORAGE_ENGINE */
 /* #undef WITH_INNOBASE_STORAGE_ENGINE */
-#define WITH_XTRADB_STORAGE_ENGINE 1
-#define WITH_CSV_STORAGE_ENGINE 1
-#define WITH_PARTITION_STORAGE_ENGINE 1
-#define WITH_PERFSCHEMA_STORAGE_ENGINE 1
+/* #undef WITH_XTRADB_STORAGE_ENGINE */
+/* #undef WITH_CSV_STORAGE_ENGINE */
+/* #undef WITH_PARTITION_STORAGE_ENGINE */
+/* #undef WITH_PERFSCHEMA_STORAGE_ENGINE */
 /* #undef WITH_NDBCLUSTER_STORAGE_ENGINE */
 #if (WITH_NDBCLUSTER_STORAGE_ENGINE) && !defined(EMBEDDED_LIBRARY)
 # define HAVE_NDB_BINLOG 1
 #endif
-#define WITH_ARIA_STORAGE_ENGINE 1
-#define USE_ARIA_FOR_TMP_TABLES 1
+/* #undef WITH_ARIA_STORAGE_ENGINE */
+/* #undef USE_ARIA_FOR_TMP_TABLES */
 
 #define DEFAULT_MYSQL_HOME "/usr/local"
 #define SHAREDIR "/usr/local/share/mysql"
@@ -636,16 +636,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 30
+#define MYSQL_VERSION_PATCH 32
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.30"
+#define PACKAGE_STRING "MySQL Server 10.0.32"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.30"
-#define VERSION "10.0.30"
+#define PACKAGE_VERSION "10.0.32"
+#define VERSION "10.0.32"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
@@ -663,21 +663,4 @@
 #define __STDC_FORMAT_MACROS
 #endif
 
-/*
-  stat structure (from <sys/stat.h>) is conditionally defined
-  to have different layout and size depending on the defined macros.
-  The correct macro is defined in my_config.h, which means it MUST be
-  included first (or at least before <features.h> - so, practically,
-  before including any system headers).
-
-  Check the include order by looking at __GLIBC__ (defined in <features.h>)
-
-  But we cannot force all third-party clients/connectors to include
-  my_config.h first. So, their crashes are their responsibility,
-  we enable this check only for MariaDB sources (SAFE_MUTEX check).
-*/
-#if defined(__GLIBC__) && defined(SAFE_MUTEX)
-#error <my_config.h> MUST be included first!
-#endif
-
 #endif
